IndexedRegisterProxyMut

Struct IndexedRegisterProxyMut 

pub struct IndexedRegisterProxyMut<'a, M: Mmio + ?Sized, R: IndexedRegister> { /* private fields */ }
A mutable proxy struct for interacting with a specific IndexedRegister over a specific Mmio.

Implementations

Source

impl<'a, M: Mmio + ?Sized, R: IndexedRegister> IndexedRegisterProxyMut<'a, M, R>

pub fn new(mmio: &'a mut M) -> Self

Creates a new proxy.

Source

impl<'a, M: Mmio + ?Sized, R: ReadableIndexedRegister> IndexedRegisterProxyMut<'a, M, R>

pub fn read(&self, index: usize) -> R

Reads the register from MMIO at the specified index.

Source

impl<'a, M: Mmio + ?Sized, R: WritableIndexedRegister> IndexedRegisterProxyMut<'a, M, R>

pub fn write(&mut self, index: usize, val: R)

Writes the register to MMIO at the specified index.

Source

impl<'a, M: Mmio + ?Sized, R: ReadableIndexedRegister + WritableIndexedRegister> IndexedRegisterProxyMut<'a, M, R>

pub fn update<F: FnOnce(&mut R)>(&mut self, index: usize, f: F)

Reads, modifies with the closure, and writes the register back to MMIO at the specified index.