RegisterProxyMut

Struct RegisterProxyMut 

pub struct RegisterProxyMut<'a, M: Mmio + ?Sized, R: Register> { /* private fields */ }
A mutable proxy struct for interacting with a specific Register over a specific Mmio.

Implementations

Source

impl<'a, M: Mmio + ?Sized, R: Register> RegisterProxyMut<'a, M, R>

pub fn new(mmio: &'a mut M) -> Self

Creates a new proxy.

Source

impl<'a, M: Mmio + ?Sized, R: ReadableRegister> RegisterProxyMut<'a, M, R>

pub fn read(&self) -> R

Reads the register from MMIO.

Source

impl<'a, M: Mmio + ?Sized, R: WritableRegister> RegisterProxyMut<'a, M, R>

pub fn write(&mut self, val: R)

Writes the register to MMIO.

Source

impl<'a, M: Mmio + ?Sized, R: ReadableRegister + WritableRegister> RegisterProxyMut<'a, M, R>

pub fn update<F: FnOnce(&mut R)>(&mut self, f: F)

Reads, modifies with the closure, and writes the register back to MMIO.