WritableIndexedRegister

Trait WritableIndexedRegister 

pub trait WritableIndexedRegister: IndexedRegister {
    // Provided method
    fn write_index<M: Mmio + ?Sized>(&self, mmio: &mut M, index: usize) { ... }
}
A trait for indexed registers that can be written.

Provided Methods

fn write_index<M: Mmio + ?Sized>(&self, mmio: &mut M, index: usize)

Stores the register’s state at index into the MMIO region.

The offset is calculated as BASE_OFFSET + (index * STRIDE).

Panics

This method will panic if index is greater than or equal to COUNT.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors