RegisterReadAccess

Trait RegisterReadAccess 

pub trait RegisterReadAccess<M: Mmio + ?Sized> {
    type ReadProxy<'a>
       where M: 'a;

    // Required method
    fn get_read_proxy<'a>(mmio: &'a M) -> Self::ReadProxy<'a>;
}
A trait that allows a register to define its default read proxy type.

Required Associated Types

type ReadProxy<'a> where M: 'a

The proxy type used to read this register.

Required Methods

fn get_read_proxy<'a>(mmio: &'a M) -> Self::ReadProxy<'a>

Creates a new read proxy for this register using the provided MMIO region.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors