RegisterWriteAccess

Trait RegisterWriteAccess 

pub trait RegisterWriteAccess<M: Mmio + ?Sized> {
    type WriteProxy<'a>
       where M: 'a;

    // Required method
    fn get_write_proxy<'a>(mmio: &'a mut M) -> Self::WriteProxy<'a>;
}
A trait that allows a register to define its default write proxy type.

Required Associated Types

type WriteProxy<'a> where M: 'a

The proxy type used to write this register.

Required Methods

fn get_write_proxy<'a>(mmio: &'a mut M) -> Self::WriteProxy<'a>

Creates a new write proxy for this register using the provided MMIO region.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors